core_packages: Functions to Install all Core Libraries

View source: R/utils-lib-loads.R

core_packagesR Documentation

Functions to Install all Core Libraries

Description

Lists the core packages necessary to run all potential modeling algorithms.

Usage

core_packages()

Details

Lists the core packages necessary to run all potential modeling algorithms.

Value

A character vector

Author(s)

Steven P. Sanderson II, MPH

See Also

Other Utility: check_duplicate_rows(), create_splits(), create_workflow_set(), fast_classification_parsnip_spec_tbl(), fast_regression_parsnip_spec_tbl(), full_internal_make_wflw(), install_deps(), load_deps(), match_args(), quantile_normalize()

Examples

core_packages()


tidyAML documentation built on Aug. 25, 2026, 1:08 a.m.