A tibble with an added class of 'fst_reg_spec_tbl'
Arguments
.parsnip_fns
The default for this is set to all. This means that all
of the parsnip linear regression functions will be used, for example linear_reg(),
or cubist_rules. You can also choose to pass a c() vector like c("linear_reg","cubist_rules")
.parsnip_eng
The default for this is set to all. This means that all
of the parsnip linear regression engines will be used, for example lm, or
glm. You can also choose to pass a c() vector like c('lm', 'glm')
Author
Steven P. Sanderson II, MPH
Details
Creates a tibble of parsnip regression model specifications. This will
create a tibble of 46 different regression model specifications which can be
filtered. The model specs are created first and then filtered out. This will
only create models for regression problems. To find all of the supported
models in this package you can visit https://www.tidymodels.org/find/parsnip/