Learn R Programming

tidyAML (version 0.0.6)

internal_make_wflw: Internals Safely Make Workflow from Model Spec tibble

Description

Safely Make a workflow from a model spec tibble.

Usage

internal_make_wflw(.model_tbl, .rec_obj)

Value

A list object of workflows.

Arguments

.model_tbl

The model table that is generated from a function like fast_regression_parsnip_spec_tbl(), must have a class of "tidyaml_mod_spec_tbl".

.rec_obj

The recipe object that is going to be used to make the workflow object.

Author

Steven P. Sanderson II, MPH

Details

Create a model specification tibble that has a workflows::workflow() list column.

See Also

Other Internals: internal_make_fitted_wflw(), internal_make_spec_tbl(), internal_make_wflw_gee_lin_reg(), internal_make_wflw_predictions(), internal_set_args_to_tune(), make_classification_base_tbl(), make_regression_base_tbl()

Examples

Run this code
library(recipes, quietly = TRUE)

mod_spec_tbl <- fast_regression_parsnip_spec_tbl(
  .parsnip_eng = c("lm","glm","gee"),
  .parsnip_fns = "linear_reg"
)

rec_obj <- recipe(mpg ~ ., data = mtcars)

internal_make_wflw(mod_spec_tbl, rec_obj)

Run the code above in your browser using DataLab