A tibble with an added class of 'fst_class_spec_tbl'
Arguments
.parsnip_fns
The default for this is set to all. This means that all
of the parsnip classification functions will be used, for example bag_mars(),
or bart(). You can also choose to pass a c() vector like c("barg_mars","bart")
.parsnip_eng
The default for this is set to all. This means that all
of the parsnip classification engines will be used, for example earth, or
dbarts. You can also choose to pass a c() vector like c('earth', 'dbarts')
Author
Steven P. Sanderson II, MPH
Details
Creates a tibble of parsnip classification model specifications. This will
create a tibble of 32 different classification model specifications which can be
filtered. The model specs are created first and then filtered out. This will
only create models for classification problems. To find all of the supported
models in this package you can visit https://www.tidymodels.org/find/parsnip/